YOS CUBE is the name of the `YOS <http://yos.io>`_ command line tool, packaged as yos-cube, which enables the full YOS workflow: repositories version control, maintaining dependencies, publishing code, updating from remotely hosted repositories, and invoking MXCHIP YOS's own build system and export functions, among other operations.


Installation
============
YOS CUBE is a Python script, so you'll need Python installed in order to use it. YOS CUBE was tested with Python 2.7.

YOS CUBE supports Git repositories, so you'll also need to install Git.

Get Started
===========
The best way to get started is to `read the documentation on <https://code.aliyun.com/yos/yos-cube/README.md>`_.

License
=======
YOS CUBE is licensed under Apache-2.0
